@@ -1,6 +1,6 @@
 package Tie::Array::Packed;
 
-our $VERSION = '0.11';
+our $VERSION = '0.13';
 
 use strict;
 use warnings;
@@ -9,10 +9,11 @@ use Carp;
 require XSLoader;
 XSLoader::load('Tie::Array::Packed', $VERSION);
 
-my @short = qw(c C F f d i I j J s! S! l! L! n N v V q Q);
+my @short = qw(c C F f d i I j J s! S! l! L! n N v V q Q e E);
 
 my %map = ( Char => 'c',
             UnsignedChar => 'C',
+            Hex => 'h',
             NV => 'F',
             Number => 'F',
             FloatNative => 'f',
@@ -41,6 +42,10 @@ my %map = ( Char => 'c',
             UnsignedQuad => 'Q',
             LongLong => 'q',
             UnsignedLongLong => 'Q',
+            Int64 => 'q',
+            UInt64 => 'Q',
+            Int128 => 'e',
+            UInt128 => 'E',
           );
 
 
@@ -172,7 +177,7 @@ All the values on a Tie::Array::Packed array are of the same value
 (integers, shorts, doubles, etc.)
 
 The module is written in XS for speed. Tie::Array::Packed arrays are
-aproximately 15 times slower than native ones (for comparison to a
+approximately 15 times slower than native ones (for comparison to a
 pure Perl implementation, arrays tied with L<Tie::Array::PackedC> are
 around 60 times slower than native arrays).
 
@@ -214,23 +219,34 @@ and are as follows:
   Tie::Array::Packed::UnsignedLongVax        V     -
   Tie::Array::Packed::UnsignedLongLE         V     -
 
-if your C compiler has support for 64bit long long integers, then this two
-classes will be also available:
+If your Perl was compiled with 64bit support or the module
+L<Math::Int64> is installed, then the following two classes are also
+available:
 
-                                           pack      C
+                                          pack      C
             class name                    pattern   type
   --------------------------------------------------------------------
-  Tie::Array::Packed::Quad                   q     long long
-  Tie::Array::Packed::UnsignedQuad           Q     unsigned long long
+  Tie::Array::Packed::Quad                   q     int64_t
+  Tie::Array::Packed::UnsignedQuad           Q     uint64_t
+
+If your C compiler supports 128bit integers and the module
+L<Math::Int128> is installed, then the following two classes are also
+available:
+
+                                          pack      C
+            class name                    pattern   type
+  --------------------------------------------------------------------
+  Tie::Array::Packed::Int128                 e     int128_t
+  Tie::Array::Packed::UInt128                E     uint128_t
 
 
-The tie interface for those clases is:
+
+The tie interface for all these classes is as follows
+(Tie::Array::Packed::Integer is used as an example):
 
   tie @foo, Tie::Array::Packed::Integer;
   tie @foo, Tie::Array::Packed::Integer, $init_string, @values
 
-(Tie::Array::Packed::Integer is used for example, the same applies to
-the rest of the classes).
 
 When a scalar value C<$init_string> is passed as an argument
 it is used as the initial value for the storage scalar.
@@ -246,7 +262,7 @@ Additional arguments are used to initialize the array, for instance:
   tie @doz, Tie::Array::Packed::Char, 'hello', 1, 2, 3;
   print "@doz"; # prints "1 2 3 108 111";
 
-The underlaying storage scalar can be accessed unreferencing the
+The underlying storage scalar can be accessed dereferencing the
 object returned by tie:
 
   my $obj = tied(@foo);
@@ -307,12 +323,46 @@ reverses the order of the elements packed into the array
 
 See L<Sort::Packed> for the details about these methods.
 
+=item tied(@foo)->bsearch($v)
+
+When called on a sorted packed array, this method uses the binary
+search algorithm to find and return the index of the given value.
+
+Returns undef if the value is not found.
+
+Note that the method does not check if the array is ordered.
+
+=item tied(@foo)->bsearch_le($v)
+
+Similar to C<bsearch>, returns the index of the biggest
+element equal to the given value or lesser.
+
+Returns undef when all the values on the packed array are bigger than
+the given value.
+
+=item tied(@foo)->bsearch_ge($v)
+
+Similar to C<bsearch>, returns the index of the smallest
+element equal to the given value or greater.
+
+Returns undef when all the values on the packed array are smaller than
+the given value.
+
 =back
 
-=head1 BUGS
+=head1 BUGS AND SUPPORT
 
-To report bugs on this module email me to the address that appears
-below or use the CPAN RT system.
+In order to report bugs you can send me and email to the address that
+appears below or use the CPAN RT bugtracking system available at
+L<http://rt.cpan.org>.
+
+The source for the development version of the module is hosted at
+GitHub: L<https://github.com/salva/p5-Tie-Array-Packed>.
+
+=head2 My wishlist
+
+If you like this module and you're feeling generous, take a look at my
+Amazon Wish List: L<http://amzn.com/w/1WU1P6IR5QZ42>
 
 =head1 SEE ALSO
 
@@ -329,7 +379,7 @@ L<Array::Packed> is implemented in C but only supports integer values.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006-2008, 2011-2012 by Salvador FandiE<ntilde>o
+Copyright (C) 2006-2008, 2011-2013 by Salvador FandiE<ntilde>o
 (sfandino@yahoo.com).
 
 Some parts copied from Tie::Array::PackedC (C) 2003-2006 by Yves
